'use strict';
const Generator = require('yeoman-generator');
const chalk = require('chalk');
const yosay = require('yosay');
const mkdirp = require('mkdirp');

module.exports = class extends Generator {
  prompting() {
    // Have Yeoman greet the user.
    this.log(yosay(
      'Welcome to the first-class ' + chalk.red('generator-android-mvp-rx-loader-arch') + ' generator!'
    ));

    const prompts = [{
        name: 'name',
        message: 'What are you calling your app?',
        store: true,
        default: this.appname // Default to current folder name
      },
      {
        name: 'package',
        message: 'What package will you be publishing the app under?',
        store: true
      },
      {
        name: 'targetSdk',
        message: 'What Android SDK will you be targeting?',
        store: true,
        default: 23 // Android 6.0 (Marshmallow)
      },
      {
        name: 'minSdk',
        message: 'What is the minimum Android SDK you wish to support?',
        store: true,
        default: 15 // Android 4.0 (Ice Cream Sandwich)
      }];

    return this.prompt(prompts).then(props => {
      // To access props later use this.props.someAnswer;
      this.props = props;
    });
  }

  writing() {
    var packageDir = this.props.package.replace(/\./g, '/');
    
    this.fs.copy(this.templatePath('gradle'),this.destinationPath('gradle'));
    this.fs.copy(this.templatePath('.gitignore'),this.destinationPath('.gitignore'));
    this.fs.copy(this.templatePath('build.gradle'),this.destinationPath('build.gradle'));
    this.fs.copy(this.templatePath('gradle.properties'),this.destinationPath('gradle.properties'));
    this.fs.copy(this.templatePath('gradlew'),this.destinationPath('gradlew'));
    this.fs.copy(this.templatePath('gradlew.bat'),this.destinationPath('gradlew.bat'));
    this.fs.copy(this.templatePath('settings.gradle'),this.destinationPath('settings.gradle'));
    this.fs.copy(this.templatePath('app/.gitignore'),this.destinationPath('app/.gitignore'));
    this.fs.copy(this.templatePath('app/proguard-rules.pro'),this.destinationPath('app/proguard-rules.pro'));
    this.fs.copyTpl(this.templatePath('app/build.gradle'),this.destinationPath('app/build.gradle'),{package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});
     this.fs.copyTpl(this.templatePath('app/src/androidTest/java/ExampleInstrumentedTest.java'),this.destinationPath('app/src/androidTest/java/' + packageDir + '/ExampleInstrumentedTest.java'),{package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});
     this.fs.copyTpl(this.templatePath('app/src/test/java/ExampleUnitTest.java'),this.destinationPath('app/src/test/java/' + packageDir + '/ExampleUnitTest.java'),{package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});
     this.fs.copy(this.templatePath('app/src/main/res'),this.destinationPath('app/src/main/res'));
     this.fs.copyTpl(this.templatePath('app/src/main/java/app'),this.destinationPath('app/src/main/java/'+packageDir + '/app'),
     {package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});
     this.fs.copyTpl(this.templatePath('app/src/main/java/base'),this.destinationPath('app/src/main/java/'+packageDir + '/base'),
     {package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});
     this.fs.copyTpl(this.templatePath('app/src/main/java/managers'),this.destinationPath('app/src/main/java/'+packageDir + '/managers'),
     {package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});
     mkdirp('app/src/main/java/'+packageDir +'/services');
     mkdirp('app/src/main/java/'+packageDir +'/loaders');
     mkdirp('app/src/main/java/'+packageDir +'/ui');
     this.fs.copyTpl(this.templatePath('app/src/main/java/utils'),this.destinationPath('app/src/main/java/'+packageDir + '/utils'),
     {package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk});    
     this.fs.copyTpl(this.templatePath('app/src/main/AndroidManifest.xml'),this.destinationPath('app/src/main/AndroidManifest.xml'),
     {package: this.props.package,minSdk: this.props.minSdk,targetSdk: this.props.targetSdk,name: this.props.name});
       
  }
};

